/*  $Id: ErrorHandler.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

/**
 * Error handler.
 * As handler, completed with services to check errors after handling
 */
public interface ErrorHandler extends Handler<Error> {
    /**
     * Checks for error.
     * Only checks. This method doesn't change the handler status.
     * @return 
     *  - true if no error handled since last check().
     *  - any other depending of error handling and user interaction.
     */
   boolean checkOnly(); 
   /**
    * Checks for error and reset handler.
    * After checking, the handler is reset to its no error state.
    */
   boolean checkAndReset();
   /**
    * Resets handler.
    * Switch the handler to its no error default state.
    */
}
