/*  $Id: WeakHashtable.java 1035 2010-06-15 13:08:33Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.xml;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/** 
 * Handler de base pour l'interpretation d'une entité.
 */
public class XmlEntityHandler<T> extends DefaultHandler {
    /** Objet en cours de deserialisation. */
    private T _build;
    /** Indique si la creation est faite et contrôlée
     */
    private boolean _buildChecked=false;
    /** Obtenir l'objet refinal staticruit */
    public T getBuild()
    {
        if (!_buildChecked)
        {
            Error err=new Error(""+getClass()+".nobuild",Error.ELevel.ERR);
            _buildChecked=true;
            _xmlReader.handleErr(err);
        }
        return _build;
    }
    /** Définir l'objet à refinal staticruire */
    protected void setBuild(T build)
    {
        _build=build;
        _buildChecked=true;
    }
    /** Indique si la refinal staticruction de l'objet en désérialisation
     * a déjà été contrôlée. /
     * @return 
     * - true : objet déjà contrôlé, inutile de signaler quoi que ce soit
     * si on final staticate qu'il manque des choses.
     * - false : objet pas encore contrôlé.
     */ 
    public boolean isBuildChecked() {
        return _buildChecked;
    }
    /** lecteur XML à consulter pour extraire l'entite.
     * @djin.relation aggregation
     */ 
    private XmlReader _xmlReader;
     /* @return Le lecteur XML associé */
    protected XmlReader getXmlReader()
    {
        return _xmlReader;
    }
    /** 
     * Nom de l'entité en cours de traitement
     */
    private String _name;
   
    private DefaultHandler _backHandler=null; 
    /** 
     * texte contenu dans l'élément
     */
    private StringBuffer _text;
    /** 
     * Création d'un nouveau handler.
     * @param xmlReader xmlReader à consulter pour
     * extraire l'entité.
     * @param name nom de l'entité à traiter
     */ 
    public XmlEntityHandler(XmlReader xmlReader,String name, 
                        DefaultHandler backHandler) {
        _xmlReader=xmlReader;
        _name=name;
        _text=new StringBuffer();
        _backHandler=backHandler;
    }

    /** 
     * Traitement individuel des sous entités rencontrées.
     * <p>Le comportement normal est de créer pour chaque sous-entité
     * reconnue un handler associé et de lui transferer le traitement.
     * </p>
     * @param name nom de l'entité
     */ 
    public void startElement(String uri, String localName,
                         String qName, Attributes atts) throws SAXException {
        // par defaut signaler entite inconnue.
        Error err=new Error(""+getClass()+".unexpelem",Error.ELevel.WARN);
        err.addArg(_name);
        _xmlReader.handleErr(err);
    }	
    /** 
     * L'élément a été traité et le texte contenu est disponible.
     */
    public void endElement(String uri, String localName,
                            String qName) throws SAXException {
        if (checkElement(_name,localName,qName)) {
            if (_backHandler!=null) {
                _xmlReader.setHandler(_backHandler);
            }
        }
    }

    public void characters(char[] ch, int start, int length) {
        _text.append(ch,start,length);
    }
	
    public String getText() 
    {
        return _text.toString();
    }	

    protected void resetText() {
        _text=new StringBuffer();
    }

    static protected boolean checkElement(String candidate,
                                    String name, String qName) {
		return candidate.equals(name) || candidate.equals(qName);
	}
    protected boolean checkElement(String name, String qName) {
		return _name.equals(name) || _name.equals(qName);
	}
}
